==> mathjax_2.7.0.orig.tar.xz: MathJax-2.7.0/unpacked/localization/br/HelpDialog.js <==
/*************************************************************
 *
 *  MathJax/localization/br/HelpDialog.js
 *
 *  Copyright (c) 2009-2016 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
MathJax.Localization.addTranslation("br","HelpDialog",{
        version: "2.7.0",
        isLoaded: true,
        strings: {
          Help: "Sikour MathJax",
          MathJax: "*MathJax* zo ul levraoueg JavaSkript. Ganta\u00F1 e c'hall aozerien ar pajenno\u00F9 enderc'hel jedado\u00F9 en o fajenno\u00F9 Web. Evel lenner n'ho po ket ezhomm d'ober netra evit ma'z aio en-dro.",
          Browsers: "\"Merdeerien\": Mont a ra Mathjax en-dro gant an holl verdeerien modern, en ur gonta\u00F1 Explorer 6, Firefox 3, Chrome 0.2, Safari 2, Opera 9.6 hag o stummo\u00F9 kre\u00F1voc'h, hag ivez an darn vrasa\u00F1 eus ar merdeerio\u00F9 evit hezougello\u00F9 ha tablezenno\u00F9.",
          Menu: "\"La\u00F1ser Math\" : Ouzhpenna\u00F1 a ra MathJax ul la\u00F1ser kemperzhel  d'ar c'hevatalenno\u00F9. Klikit war bouton deho\u00F9 al logodenn pe klikit war war ne vern peseurt formulenn jedoniezh o terc'hel da boueza\u00F1 war Ktrl evit monet d'al la\u00F1ser.",
          ShowMath: "Gant \"Diskwel ar matematiko\u00F9 evel\" e c'hallot diskwel balizenna\u00F1 tarzh ar jedad evit eila\u00F1-pega\u00F1 (evel MathML pe en e furmad orin).",
          Settings: "Gant *Arventenno\u00F9\" e c'hallit kontrolla\u00F1 arc'hwelio\u00F9 MathJax, evel ment ar jedado\u00F9, hag ar gwikefre implijet evit diskwel ar c'hevatalenno\u00F9."
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/br/HelpDialog.js");

==> mathjax_2.7.3+dfsg.orig.tar.xz: MathJax-2.7.3/unpacked/localization/br/HelpDialog.js <==
/*************************************************************
 *
 *  MathJax/localization/br/HelpDialog.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
MathJax.Localization.addTranslation("br","HelpDialog",{
        version: "2.7.3",
        isLoaded: true,
        strings: {
          Help: "Sikour MathJax",
          MathJax: "*MathJax* zo ul levraoueg JavaSkript. Ganta\u00F1 e c'hall aozerien ar pajenno\u00F9 enderc'hel jedado\u00F9 en o fajenno\u00F9 Web. Evel lenner n'ho po ket ezhomm d'ober netra evit ma'z aio en-dro.",
          Browsers: "\"Merdeerien\": Mont a ra Mathjax en-dro gant an holl verdeerien modern, en ur gonta\u00F1 Explorer 6, Firefox 3, Chrome 0.2, Safari 2, Opera 9.6 hag o stummo\u00F9 kre\u00F1voc'h, hag ivez an darn vrasa\u00F1 eus ar merdeerio\u00F9 evit hezougello\u00F9 ha tablezenno\u00F9.",
          Menu: "\"La\u00F1ser Math\" : Ouzhpenna\u00F1 a ra MathJax ul la\u00F1ser kemperzhel  d'ar c'hevatalenno\u00F9. Klikit war bouton deho\u00F9 al logodenn pe klikit war war ne vern peseurt formulenn jedoniezh o terc'hel da boueza\u00F1 war Ktrl evit monet d'al la\u00F1ser.",
          ShowMath: "Gant \"Diskwel ar matematiko\u00F9 evel\" e c'hallot diskwel balizenna\u00F1 tarzh ar jedad evit eila\u00F1-pega\u00F1 (evel MathML pe en e furmad orin).",
          Settings: "Gant *Arventenno\u00F9\" e c'hallit kontrolla\u00F1 arc'hwelio\u00F9 MathJax, evel ment ar jedado\u00F9, hag ar gwikefre implijet evit diskwel ar c'hevatalenno\u00F9.",
          Language: "\"Yezh\" a lez ac'hanoc'h da zibab ar yezh implijet gant MathJax evit e la\u00F1serio\u00F9 hag e gemennadurio\u00F9.",
          Zoom: "*Math zoom*: M'eo diaes deoc'h lenn ur gevatalenn e c'hall MathJax brasaat anezhi evit skoazella\u00F1 ac'hanoc'h da welet anezhi gwelloc'h.",
          Accessibilty: "*Monedusted*:Mathjad a labouro ent emgefreek gant lennerio\u00F9 skramm evit ma vo aesoc'h d'an dud fall o gweled pledi\u00F1 gant ar jedoniezh.",
          Fonts: "\"Fonto\u00F9*: gant Mathjax e vo implijet ar fonto\u00F9 jedoniel zo ma vezont staliet en hoc'h urzhiataer ; anez e vo implijet ar fonto\u00F9 kavet war ar Web. Daoust ma n'eo ret, gant ar fonto\u00F9 staliet ent lec'hel e vo buanaet ar c'henaozadur. Alia\u00F1 a reomp ac'hanoc'h da stalia\u00F1 ar [fonto\u00F9 STIX](%1).",
          CloseDialog: "Serri\u00F1 ar voest kendivizout skoazell"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/br/HelpDialog.js");
